@@ -24,41 +24,41 @@ from ..decorators import integration_test_setup, IntegrationTestDependencies
 class TestAuthClient(IBMTestCase):
     """Tests for the AuthClient."""
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_valid_login(self, dependencies: IntegrationTestDependencies) -> None:
         """Test valid authentication."""
         client = self._init_auth_client(dependencies.token, dependencies.url)
         self.assertTrue(client.access_token)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_url_404(self, dependencies: IntegrationTestDependencies) -> None:
         """Test login against a 404 URL"""
         url_404 = re.sub(r"/api.*$", "/api/TEST_404", dependencies.url)
         with self.assertRaises(ApiError):
             _ = self._init_auth_client(dependencies.token, url_404)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_token(self, dependencies: IntegrationTestDependencies) -> None:
         """Test login using invalid token."""
         qe_token = "INVALID_TOKEN"
         with self.assertRaises(ApiError):
             _ = self._init_auth_client(qe_token, dependencies.url)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_url_unreachable(self, dependencies: IntegrationTestDependencies) -> None:
         """Test login against an invalid (malformed) URL."""
         qe_url = "INVALID_URL"
         with self.assertRaises(ApiError):
             _ = self._init_auth_client(dependencies.token, qe_url)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_api_version(self, dependencies: IntegrationTestDependencies) -> None:
         """Check the version of the QX API."""
         client = self._init_auth_client(dependencies.token, dependencies.url)
         version = client.api_version()
         self.assertIsNotNone(version)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_user_urls(self, dependencies: IntegrationTestDependencies) -> None:
         """Check the user urls of the QX API."""
         client = self._init_auth_client(dependencies.token, dependencies.url)
@@ -66,7 +66,7 @@ class TestAuthClient(IBMTestCase):
         self.assertIsNotNone(user_urls)
         self.assertTrue("http" in user_urls and "ws" in user_urls)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_user_hubs(self, dependencies: IntegrationTestDependencies) -> None:
         """Check the user hubs of the QX API."""
         client = self._init_auth_client(dependencies.token, dependencies.url)
@@ -80,5 +80,5 @@ class TestAuthClient(IBMTestCase):
 
     def _init_auth_client(self, token, url):
         """Return an AuthClient."""
-        params = ClientParameters(auth_type="legacy", token=token, url=url)
+        params = ClientParameters(channel="ibm_quantum", token=token, url=url)
         return AuthClient(params)
