@@ -55,7 +55,7 @@ class TestProxies(IBMTestCase):
             # wait for the process to terminate
             self.proxy_process.wait()
 
-    @integration_test_setup(supported_auth=["cloud"])
+    @integration_test_setup(supported_channel=["ibm_cloud"])
     def test_proxies_cloud_runtime_client(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
@@ -70,13 +70,13 @@ class TestProxies(IBMTestCase):
         proxy_output = self.proxy_process.stdout.read().decode("utf-8")
         self.assertIn(api_line, proxy_output)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
-    def test_proxies_legacy_runtime_client(
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
+    def test_proxies_ibm_quantum_runtime_client(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should reach the proxy using RuntimeClient."""
         service = IBMRuntimeService(
-            auth="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies={"urls": VALID_PROXIES},
@@ -94,13 +94,13 @@ class TestProxies(IBMTestCase):
         # Check if the API call (querying providers list) went through proxy.
         self.assertIn(api_line, proxy_output)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_proxies_account_client(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should reach the proxy using AccountClient."""
         service = IBMRuntimeService(
-            auth="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies={"urls": VALID_PROXIES},
@@ -118,7 +118,7 @@ class TestProxies(IBMTestCase):
         # Check if the API call (querying providers list) went through proxy.
         self.assertIn(api_line, proxy_output)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_proxies_authclient(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
@@ -127,7 +127,7 @@ class TestProxies(IBMTestCase):
             dependencies.url
         )
         params = ClientParameters(
-            auth_type="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=VALID_PROXIES),
@@ -141,7 +141,7 @@ class TestProxies(IBMTestCase):
             self.proxy_process.stdout.read().decode("utf-8"),
         )
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_proxies_versionclient(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
@@ -159,13 +159,13 @@ class TestProxies(IBMTestCase):
             self.proxy_process.stdout.read().decode("utf-8"),
         )
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_proxy_port_runtime_client(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should raise RequestApiError with ProxyError using RuntimeClient."""
         params = ClientParameters(
-            auth_type="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_PORT_PROXIES),
@@ -175,13 +175,13 @@ class TestProxies(IBMTestCase):
             client.list_programs(limit=1)
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_proxy_port_authclient(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should raise RequestApiError with ProxyError using AuthClient."""
         params = ClientParameters(
-            auth_type="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_PORT_PROXIES),
@@ -191,7 +191,7 @@ class TestProxies(IBMTestCase):
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_proxy_port_versionclient(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
@@ -204,13 +204,13 @@ class TestProxies(IBMTestCase):
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_proxy_address_runtime_client(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should raise RequestApiError with ProxyError using RuntimeClient."""
         params = ClientParameters(
-            auth_type="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_ADDRESS_PROXIES),
@@ -221,13 +221,13 @@ class TestProxies(IBMTestCase):
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_proxy_address_authclient(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
         """Should raise RequestApiError with ProxyError using AuthClient."""
         params = ClientParameters(
-            auth_type="legacy",
+            channel="ibm_quantum",
             token=dependencies.token,
             url=dependencies.url,
             proxies=ProxyConfiguration(urls=INVALID_ADDRESS_PROXIES),
@@ -237,7 +237,7 @@ class TestProxies(IBMTestCase):
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_invalid_proxy_address_versionclient(
         self, dependencies: IntegrationTestDependencies
     ) -> None:
@@ -250,7 +250,7 @@ class TestProxies(IBMTestCase):
 
         self.assertIsInstance(context_manager.exception.__cause__, ProxyError)
 
-    @integration_test_setup(supported_auth=["legacy"], init_service=False)
+    @integration_test_setup(supported_channel=["ibm_quantum"], init_service=False)
     def test_proxy_urls(self, dependencies: IntegrationTestDependencies) -> None:
         """Test different forms of the proxy urls."""
         test_urls = [
@@ -261,7 +261,7 @@ class TestProxies(IBMTestCase):
         for proxy_url in test_urls:
             with self.subTest(proxy_url=proxy_url):
                 params = ClientParameters(
-                    auth_type="legacy",
+                    channel="ibm_quantum",
                     token=dependencies.token,
                     url=dependencies.url,
                     proxies=ProxyConfiguration(urls={"https": proxy_url}),
