@@ -18,7 +18,7 @@ import time
 import unittest
 from unittest import mock
 
-from qiskit import QuantumCircuit
+from qiskit.circuit import QuantumCircuit
 from qiskit.providers.jobstatus import JOB_FINAL_STATES, JobStatus
 from qiskit.providers.exceptions import QiskitBackendNotFoundError
 from qiskit_ibm_runtime.hub_group_project import HubGroupProject
@@ -87,7 +87,7 @@ def get_hgp(qe_token: str, qe_url: str, default: bool = True) -> HubGroupProject
         A HubGroupProject, as specified by `default`.
     """
     service = IBMRuntimeService(
-        auth="legacy", token=qe_token, url=qe_url
+        channel="ibm_quantum", token=qe_token, url=qe_url
     )  # Default hub/group/project.
     open_hgp = service._get_hgp()  # Open access hgp
     hgp_to_return = open_hgp
